"""
PyGMI stands for Python Geoscience Modelling and Interpretation.

It is a modelling and interpretation suite aimed at magnetic, gravity and other
datasets. It includes:

 * Magnetic and Gravity 3D forward modelling
 * Remote sensing tools.
 * Cluster Analysis
 * Routines for cutting, reprojecting and doing simple modifications to data
 * Convenient display of data using pseudo-color, ternary and sunshading

It is released under the Gnu General Public License version 3.0
"""

from pygmi.version import __version__
